# FIVE4 Tools for Data Manipulation and Cleaning
```language
from five4_tools.five4_utils import Operaciones

ds = 'five4_tools/IQVIA_Dataset.csv'
datosA = Operaciones(ds)
datosA.nullDataResume()
datosA.resumenShape()

```
![Registros](https://github.com/Five4-Argentina/five4_tools/blob/main/Example.png?raw=true)